@@ -1,12 +1,12 @@
 ;;; vc-got.el --- VC backend for Game of Trees VCS   -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2021  Free Software Foundation, Inc.
+;; Copyright (C) 2021-2022  Free Software Foundation, Inc.
 
 ;; Author: Omar Polo <op@omarpolo.com>
 ;;         Timo Myyrä <timo.myyra@bittivirhe.fi>
 ;; URL: https://projects.omarpolo.com/vc-got.html
 ;; Keywords: vc tools
-;; Version: 1.1.1
+;; Version: 1.1.2
 ;; Package-Requires: ((emacs "25.1"))
 
 ;; This program is free software; you can redistribute it and/or modify
@@ -178,13 +178,22 @@ If nil, use the value of `vc-diff-switches'.  If t, use no switches."
   (when (version<= version emacs-version)
     `(progn ,@body)))
 
-(defun vc-got--program-version ()
+(defun vc-got--version ()
   "Return string representing the got version."
   (let (process-file-side-effects)
     (with-temp-buffer
       (vc-got--call "-V")
       (substring (buffer-string) 4 -1))))
 
+(defun vc-got--version<= (target)
+  "Compare the current version against TARGET.
+Takes care of handling the -current suffix."
+  (let* ((version-string (vc-got--version))
+         (current-version (string-replace "-current" "" version-string)))
+    (when (version<= current-version target)
+      ;; let X.Y-current sort *after* X.Y
+      (string= version-string current-version))))
+
 (defun vc-got-root (file)
   "Return the work tree root for FILE, or nil."
   (vc-find-root file ".got"))
@@ -227,7 +236,13 @@ INCLUDE-DIFF: display the patch of modifications made in each commit.
 
 Return nil if the command failed or if PATH isn't included in any
 worktree."
-  (let ((process-file-side-effects nil))
+  (let* ((process-file-side-effects nil)
+         ;; got 0.71-current at some point switched to -S for search
+         ;; pattern and -s for the one-line format.
+         ;; XXX: remove in a few releases.
+         (search-flag (if (vc-got--version<= "0.71")
+                          "-s"
+                        "-S")))
     (vc-got-with-worktree (or path default-directory)
       (when (zerop
              (save-excursion
@@ -235,7 +250,8 @@ worktree."
                              (and limit (list "-l" (format "%s" limit)))
                              (and start-commit (list "-c" start-commit))
                              (and stop-commit (list "-x" stop-commit))
-                             (and search-pattern (list "-s" search-pattern))
+                             (and search-pattern (list search-flag
+                                                       search-pattern))
                              (and reverse '("-R"))
                              (and include-diff '("-p"))
                              ;; "--"
@@ -246,7 +262,7 @@ worktree."
           t)))))
 
 (defun vc-got--status (status-codes dir-or-file &optional files)
-  "Return a list of lists '(FILE STATUS STAGE-STATUS).
+  "Return a list of lists (FILE STATUS STAGE-STATUS).
 DIR-OR-FILE can be either a directory or a file.  If FILES is
 given, return the status of those files, otherwise the status of
 DIR-OR-FILE.  STATUS-CODES is either nil, or a string that's
@@ -401,10 +417,9 @@ files on disk."
   (let (process-file-side-effects)
     (vc-got-with-worktree default-directory
       (with-temp-buffer
-        (if (zerop (vc-got--call "branch" "--" name))
-            t
-          (error "[vc-got] can't create branch %s: %s" name
-                 (buffer-string)))))))
+        (or (zerop (vc-got--call "branch" "--" name))
+            (error "[vc-got] can't create branch %s: %s" name
+                   (buffer-string)))))))
 
 
 ;; Backend properties
@@ -432,8 +447,7 @@ files on disk."
       nil                               ; got doesn't track directories
     (when (vc-find-root file ".got")
       (let ((s (vc-got-state file)))
-        (not (or (eq s 'unregistered)
-                 (null s)))))))
+        (not (memq s '(nil unregistered)))))))
 
 (defun vc-got-state (file)
   "Return the current version control state of FILE.  See `vc-state'."
